@@ -60,27 +60,6 @@ void BacktraceParserTest::btParserUsefulnessTest()
     QCOMPARE(btUsefulness, result);
 }
 
-void BacktraceParserTest::btParserFunctionsTest_data()
-{
-    fetchData(QStringLiteral("firstValidFunctions"));
-}
-
-void BacktraceParserTest::btParserFunctionsTest()
-{
-    QFETCH(QString, filename);
-    QFETCH(QString, result);
-    QFETCH(QString, debugger);
-
-    // parse
-    QSharedPointer<BacktraceParser> parser(BacktraceParser::newParser(debugger));
-    parser->connectToGenerator(m_generator);
-    m_generator->sendData(filename);
-
-    // compare
-    QString functions = parser->firstValidFunctions().join(QLatin1Char('|'));
-    QCOMPARE(functions, result);
-}
-
 void BacktraceParserTest::btParserBenchmark_data()
 {
     QTest::addColumn<QString>("filename");
